---
-- Contains definitions for the LDB data source.
-- @file XToLevel.Average.lua
-- @release 3.3.3_12r
-- @copyright Atli Þór (atli@advefir.com)
-- @license MIT/X11
---
XToLevel.Average =
{
    activeAPI = "Blocky",
    knownAPIs = {
        "Blocky",
        "Classic"
    }
}

---
-- Initialize the Average control methods. This basically just sets
-- which API should be used.
function XToLevel.Average:Initialize()
    self.activeAPI = self.knownAPIs[sConfig.averageDisplay.mode];
    
    for index, name in ipairs(self.knownAPIs) do
        XToLevel.AverageFrameAPI[name]:Initialize()
    end
    
    self:Update()
end

---
-- Updates the active AverageFrame window.
function XToLevel.Average:Update()
    if self.activeAPI ~= self.knownAPIs[sConfig.averageDisplay.mode] then
        for index, name in ipairs(self.knownAPIs) do
	        XToLevel.AverageFrameAPI[name]:Update()
	    end
	    self.activeAPI = self.knownAPIs[sConfig.averageDisplay.mode]
    end
    if self.activeAPI ~= nil then
	    if XToLevel.Player.isActive then
		    XToLevel.AverageFrameAPI[self.activeAPI]:SetKills       (XToLevel.Player:GetAverageKillsRemaining() or nil)
		    XToLevel.AverageFrameAPI[self.activeAPI]:SetQuests      (XToLevel.Player:GetAverageQuestsRemaining() or nil)
		    XToLevel.AverageFrameAPI[self.activeAPI]:SetDungeons    (XToLevel.Player:GetAverageDungeonsRemaining() or nil)
		    XToLevel.AverageFrameAPI[self.activeAPI]:SetBattles     (XToLevel.Player:GetAverageBGsRemaining() or nil)
		    XToLevel.AverageFrameAPI[self.activeAPI]:SetObjectives  (XToLevel.Player:GetAverageBGObjectivesRemaining() or nil)
		    XToLevel.AverageFrameAPI[self.activeAPI]:SetProgress    (round((XToLevel.Player.currentXP or 0) / (XToLevel.Player.maxXP or 1) * 100, 1))
	    end
	    if XToLevel.Pet.isActive or XToLevel.Pet.hasBeenActive then
	        XToLevel.AverageFrameAPI[self.activeAPI]:SetPetKills    (XToLevel.Pet:GetAverageKillsRemaining() or nil);
	        XToLevel.AverageFrameAPI[self.activeAPI]:SetPetProgress (floor(XToLevel.Pet.xp / XToLevel.Pet.maxXP * 100));
	    end
	    XToLevel.AverageFrameAPI[self.activeAPI]:Update()
    end
end